@@ -45,17 +45,33 @@ module Svg : sig
   type +'a attrib
   type uri = Xml.uri
 
+  (**/**)
+
+  module Ev' = Eliom_content_core.Svg.Ev'
+
+  (**/**)
+
   (** Creation of {e f}unctional content (copy-able but not referable).
 
        See {% <<a_api project="tyxml" | module Svg_sigs.T >> %} *)
   module F : sig
     (** Cf. {% <<a_api project="tyxml" | module Html_sigs.T >> %}. *)
-    module Raw :
-      Svg_sigs.Make(Xml).T
-        with type +'a elt = 'a elt
-         and type +'a attrib = 'a attrib
 
-    include module type of Raw
+    (**/**)
+
+    module Raw' :
+      Svg_sigs.Make(Xml).T
+      with type +'a elt = 'a elt
+       and type +'a attrib = 'a attrib
+
+    (**/**)
+
+    module Raw : sig
+      include module type of Raw'
+      include module type of Ev' (Raw')
+    end
+
+    include module type of Raw'
   end
 
   (** Creation of content with {e D}OM semantics (referable
@@ -63,12 +79,22 @@ module Svg : sig
        See {% <<a_api project="tyxml" | module Svg_sigs.T >> %} *)
   module D : sig
     (** Cf. {% <<a_api project="tyxml" | module Html_sigs.T >> %}. *)
-    module Raw :
-      Svg_sigs.Make(Xml).T
-        with type +'a elt = 'a elt
-         and type +'a attrib = 'a attrib
 
-    include module type of Raw
+    (**/**)
+
+    module Raw' :
+      Svg_sigs.Make(Xml).T
+      with type +'a elt = 'a elt
+       and type +'a attrib = 'a attrib
+
+    (**/**)
+
+    module Raw : sig
+      include module type of Raw'
+      include module type of Ev' (Raw')
+    end
+
+    include module type of Raw'
   end
 
   (** Creation of reactive content *)
@@ -80,8 +106,8 @@ module Svg : sig
 
     module Raw :
       Svg_sigs.Make(Eliom_content_core.Xml_wed).T
-        with type +'a elt = 'a elt
-         and type +'a attrib = 'a attrib
+      with type +'a elt = 'a elt
+       and type +'a attrib = 'a attrib
 
     include module type of Raw
   end
@@ -283,26 +309,42 @@ module Html : sig
   type uri = Xml.uri
   type 'a form_param
 
+  (**/**)
+
+  module Ev' = Eliom_content_core.Html.Ev'
+
+  (**/**)
+
   (** Creation of {e f}unctional HTML5 content (copy-able but not referable). *)
   module F : sig
     (** {2 Content creation}
         See {% <<a_api project="tyxml" | module Html_sigs.T >> %} *)
 
     (** Cf. {% <<a_api project="tyxml" | module Html_sigs.T >> %}. *)
-    module Raw :
-      Html_sigs.Make(Xml)(Svg.F.Raw).T
-        with type +'a elt = 'a elt
-         and type +'a attrib = 'a attrib
 
-    include module type of Raw
+    (**/**)
+
+    module Raw' :
+      Html_sigs.Make(Xml)(Svg.F.Raw').T
+      with type +'a elt = 'a elt
+       and type +'a attrib = 'a attrib
+
+    (**/**)
+
+    module Raw : sig
+      include module type of Raw'
+      include module type of Ev' (Raw')
+    end
+
+    include module type of Raw'
 
     include
       Eliom_content_sigs.LINKS_AND_FORMS
-        with type +'a elt := 'a elt
-         and type +'a attrib := 'a attrib
-         and type uri := uri
-         and type ('a, 'b, 'c) star := ('a, 'b, 'c) star
-         and type 'a form_param := 'a form_param
+      with type +'a elt := 'a elt
+       and type +'a attrib := 'a attrib
+       and type uri := uri
+       and type ('a, 'b, 'c) star := ('a, 'b, 'c) star
+       and type 'a form_param := 'a form_param
   end
 
   (** Creation of HTML5 content with {e D}OM semantics (referable) *)
@@ -311,20 +353,30 @@ module Html : sig
         See {% <<a_api project="tyxml" | module Html_sigs.T >> %} *)
 
     (** Cf. {% <<a_api project="tyxml" | module Html_sigs.T >> %}. *)
-    module Raw :
-      Html_sigs.Make(Xml)(Svg.D.Raw).T
-        with type +'a elt = 'a elt
-         and type +'a attrib = 'a attrib
 
-    include module type of Raw
+    (**/**)
+
+    module Raw' :
+      Html_sigs.Make(Xml)(Svg.D.Raw').T
+      with type +'a elt = 'a elt
+       and type +'a attrib = 'a attrib
+
+    (**/**)
+
+    module Raw : sig
+      include module type of Raw'
+      include module type of Ev' (Raw')
+    end
+
+    include module type of Raw'
 
     include
       Eliom_content_sigs.LINKS_AND_FORMS
-        with type +'a elt := 'a elt
-         and type +'a attrib := 'a attrib
-         and type uri := uri
-         and type ('a, 'b, 'c) star := ('a, 'b, 'c) star
-         and type 'a form_param := 'a form_param
+      with type +'a elt := 'a elt
+       and type +'a attrib := 'a attrib
+       and type uri := uri
+       and type ('a, 'b, 'c) star := ('a, 'b, 'c) star
+       and type 'a form_param := 'a form_param
   end
 
   (** Creation of HTML5 content from
@@ -352,8 +404,8 @@ module Html : sig
     (** Cf. {% <<a_api project="tyxml" | module Html_sigs.T >> %}. *)
     module Raw :
       Html_sigs.Make(Eliom_content_core.Xml_wed)(Svg.R.Raw).T
-        with type +'a elt = 'a elt
-         and type +'a attrib = 'a attrib
+      with type +'a elt = 'a elt
+       and type +'a attrib = 'a attrib
 
     include module type of Raw
   end
@@ -408,8 +460,8 @@ module Html : sig
     type 'a t
     (** Custom data with values of type ['a]. *)
 
-    val create
-      :  name:string
+    val create :
+       name:string
       -> ?default:'a
       -> to_string:('a -> string)
       -> of_string:(string -> 'a)
@@ -510,8 +562,8 @@ module Html : sig
     val children : 'a elt -> 'b elt list
     (** [children elt] returns the list of html children of [elt]. *)
 
-    val addEventListener
-      :  ?capture:bool
+    val addEventListener :
+       ?capture:bool
       -> 'a elt
       -> (#Dom_html.event as 'b) Js.t Dom_html.Event.typ
       -> ('a elt -> 'b Js.t -> bool)
@@ -548,8 +600,8 @@ module Html : sig
       val replaceChildren : 'a Id.id -> 'b elt list -> unit
       (** see [replaceChildren] *)
 
-      val addEventListener
-        :  ?capture:bool
+      val addEventListener :
+         ?capture:bool
         -> 'a Id.id
         -> (#Dom_html.event as 'b) Js.t Dom_html.Event.typ
         -> ('a elt -> 'b Js.t -> bool)
@@ -571,9 +623,9 @@ module Html : sig
     (**/**)
 
     (*
-    val get_custom_data : _ elt -> 'a Custom_data.t -> 'a
+       val get_custom_data : _ elt -> 'a Custom_data.t -> 'a
     val set_custom_data : _ elt -> 'a Custom_data.t -> 'a -> unit
- *)
+    *)
 
     module Class : sig
       val contain : 'a elt -> string -> bool
@@ -876,8 +928,8 @@ val force_link : unit
 
 (**/**)
 
-val set_client_fun
-  :  ?app:string
+val set_client_fun :
+   ?app:string
   -> service:('a, 'b, _, _, _, _, _, _, _, _, _) Eliom_service.t
   -> ('a -> 'b -> Eliom_service.result Lwt.t)
   -> unit
